scipy.io.netcdf.netcdf_variable
===============================

.. currentmodule:: scipy.io.netcdf

.. autoclass:: netcdf_variable

   

   .. HACK
      .. autosummary::
         :toctree:
      
         netcdf_variable.__init__
         netcdf_variable.assignValue
         netcdf_variable.getValue
         netcdf_variable.typecode



   

   .. HACK
      .. autosummary::
         :toctree:
      
         netcdf_variable.isrec
         netcdf_variable.shape

